@@ -9,7 +9,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::ByteStream;
 use Captcha::reCAPTCHA;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 $VERSION = eval $VERSION;
 
 sub register {
@@ -17,6 +17,8 @@ sub register {
     my $app  = shift;
     my $conf = shift || {};
 
+    $app->log->debug("Usage of Mojolicious::Plugin::Captcha::reCAPTCHA is deprecated; you should consider switching to Mojolicious::Plugin::ReCAPTCHAv2");
+
     die ref($self), ": need private and public key\n"
         unless $conf->{private_key} and $conf->{public_key};
 
@@ -86,17 +88,19 @@ sub register {
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Mojolicious::Plugin::Captcha::reCAPTCHA - use Captcha::reCAPTCHA in Mojolicious apps
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -143,7 +147,16 @@ Mojolicious::Plugin::Captcha::reCAPTCHA - use Captcha::reCAPTCHA in Mojolicious
 
 =head1 VERSION
 
-version 0.04
+version 0.05
+
+=head1 DEPRECATION NOTE
+
+Mojolicious::Plugin::Captcha::reCAPTCHA is deprecated and you should consider 
+switching to L<Mojolicious::Plugin::ReCAPTCHAv2>.
+
+The latter one uses the newer v2 API of Googles reCAPTCHA service and also has
+no dependencies besides Mojolicious (and IO::Socket::SSL, which again is a
+dependency of Mojolicious itself).
 
 =head1 METHODS/HELPERS
 
@@ -229,15 +242,10 @@ Heiko Jansen <jansen@hbz-nrw.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Hochschulbibliothekszentrum NRW (hbz).
+This software is Copyright (c) 2015 by Hochschulbibliothekszentrum NRW (hbz).
 
 This is free software, licensed under:
 
   The GNU General Public License, Version 3, June 2007
 
 =cut
-
-
-__END__
-
-
